#!/bin/bash
#
# Title: pdf2img
# Author: TheOuterLinux (https://theouterlinux.gitlab.io)
# Purpose: To make it easier to extract images from a PDF created by the
#          'exifpdf' tool.
# License: MIT
# Last updated: 2023/05/30
# Requirements:
#     - An operating system that can run BASH scripts
#     - poppler-utils    : PDF utilities (based on Poppler)
#     - coreutils        : GNU core utilities
#
# Usage:
#     /path/to/pdf2img.sh input.pdf [image-root]
#
# [image-root] is optional; without it, the image-root uses the current
# directory's name.
#

INPUTFILE="$1"
IMAGEROOT="$2"

CLEAN="\e[0m"
GREEN="\e[92m"
BLUE="\e[94m"
YELLOW="\e[93m"
RED="\e[91m"

function HELP(){
    printf ${CLEAN}
    echo ''
    printf ${BLUE}
    echo -n 'Script:  '
    printf ${YELLOW}
    echo 'img2pdf.sh'
    printf ${BLUE}
    echo -n 'Author:  '
    printf ${YELLOW}
    echo 'TheOuterLinux (https://theouterlinux.gitlab.io)'
    printf ${BLUE}
    echo -n 'Purpose: '
    printf ${YELLOW}
    echo 'To "extract" a PDF made with exifpdf.sh back to images.'
    echo '         The images should retain EXIF meta information if the'
    echo '         input PDF was created using exifpdf.sh or in a similar'
    echo '         manor.'
    echo ''
    printf ${RED}
    echo 'Usage:'
    printf ${CLEAN}
    echo ''
    echo '    "/path/to/pdf2img.sh" input.pdf [image-root]'
    echo ''
    printf ${GREEN}
    echo '[image-root] is optional but without it, the image-root uses the'
    echo 'input.pdf file-name. An "image-root" is a file-name but with numbers'
    echo 'appended to it, increasing in number as pages are processed, or at'
    echo 'least in this usage case.'
    echo ''
    printf ${CLEAN}
}

function MAIN(){
    if [ "$IMAGEROOT" = '' ]; then IMAGEROOT="${INPUTFILE%%.*}"; fi
    echo ''
    echo 'Is this PDF encrypted? If so, input it now. If not, ignore and press ENTER.'
    read -p "Password: " PASSWORD
    echo ''
    echo 'Converting PDF to individual images... Please be patient...'
    pdfimages -all "$INPUTFILE" "$IMAGEROOT" -upw "$PASSWORD"
    echo ''
    echo 'DOME! :)'
    echo ''
}

if [ "$1" = '' ] || [ "$1" = '-h' ] || [ "$1" = '--help' ]; then HELP; else MAIN; fi
